@@ -1,7 +1,7 @@
 #
 #       images.R
 #
-#         $Revision: 1.12 $     $Date: 2004/11/27 05:42:48 $
+#         $Revision: 1.13 $     $Date: 2005/01/25 23:58:22 $
 #
 #      The class "im" of raster images
 #
@@ -11,9 +11,6 @@
 #
 #     is.im()   tests class membership
 #
-#     plot.im(), image.im(), contour.im(), persp.im()
-#                      plotting functions
-#
 #     rasterx.im(), rastery.im()    
 #                      raster X and Y coordinates
 #
@@ -58,42 +55,58 @@ inherits(x,"im")
 ########   methods for class "im"
 ################################################################
 
-image.im <- function(x, ...) {
-  main <- deparse(substitute(x))
-  do.call("image",
-          resolve.defaults(list(x$xcol, x$yrow, t(x$v)),
-                           list(...),
-                           list(xlab="x", ylab="y", asp=1.0, main=main)))
+shift.im <- function(X, vec=c(0,0), ...) {
+  verifyclass(X, "im")
+  X$xrange <- X$xrange + vec[1]
+  X$yrange <- X$yrange + vec[2]
+  X$xcol <- X$xcol + vec[1]
+  X$yrow <- X$yrow + vec[2]
+  return(X)
 }
 
-persp.im <- function(x, ...) {
-  xname <- deparse(substitute(x))
-  do.call("persp",
-          resolve.defaults(list(x$xcol, x$yrow, t(x$v)),
-                           list(...),
-                           list(xlab="x", ylab="y", zlab=xname),
-                           list(main=xname)))
+"[.im" <- subset.im <-
+function(x, i, j, drop=TRUE, ...) {
+  if(verifyclass(i, "ppp", fatal=FALSE) && missing(j)) {
+    # 'i' is a point pattern
+    # Look up the greyscale values for the points of the pattern
+    values <- lookup.im(x, i$x, i$y, naok=TRUE)
+    if(drop) return(values[!is.na(values)]) else return(values)
+  }
+  if(verifyclass(i, "owin", fatal=FALSE) && missing(j)) {
+    # 'i' is a window
+    # if drop = FALSE, just set values outside window to NA
+    # if drop = TRUE, extract values for all pixels inside window
+    #                 as an image (if 'i' is a rectangle)
+    #                 or as a vector (otherwise)
+
+    xy <- expand.grid(y=x$yrow,x=x$xcol)
+    inside <- inside.owin(xy$x, xy$y, i)
+    if(!drop) { 
+      x$v[!inside] <- NA
+      return(x)
+    } else if(i$type != "rectangle") {
+      return(x$v[inside])
+    } else {
+      disjoint <- function(r, s) { (r[2] < s[1]) || (r[1] > s[2])  }
+      clip <- function(r, s) { c(max(r[1],s[1]), min(r[2],s[2])) }
+      inrange <- function(x, r) { (x >= r[1]) & (x <= r[2]) }
+      if(disjoint(i$xrange, x$xrange) || disjoint(i$yrange, x$yrange))
+        # empty intersection
+        return(numeric(0))
+      xr <- clip(i$xrange, x$xrange)
+      yr <- clip(i$yrange, x$yrange)
+      colsub <- inrange(x$xcol, xr)
+      rowsub <- inrange(x$yrow, yr)
+      return(im(x$v[rowsub,colsub], x$xcol[colsub], x$yrow[rowsub]))
+    } 
+  }
+  stop("The subset operation is undefined for this type of index")
 }
 
-contour.im <- function (x, ...)
-{
-  main <- deparse(substitute(x))
-  add <- resolve.defaults(list(...), list(add=FALSE))$add
-  if(!add) 
-    do.call("plot",
-            resolve.defaults(list(range(x$xcol), range(x$yrow), type="n"),
-                             list(...),
-                             list(asp = 1, xlab="x", ylab="y", main=main)))
-  do.call("contour",
-          resolve.defaults(list(x$xcol, x$yrow, t(x$v), add=TRUE),
-                           list(...)))
-}
-
-plot.im <- image.im
 
 
 ################################################################
-########   other stuff
+########   other tools
 ################################################################
 
 #
@@ -166,52 +179,5 @@ rastery.im <- function(x) {
 
 ##############
 
-shift.im <- function(X, vec=c(0,0), ...) {
-  verifyclass(X, "im")
-  X$xrange <- X$xrange + vec[1]
-  X$yrange <- X$yrange + vec[2]
-  X$xcol <- X$xcol + vec[1]
-  X$yrow <- X$yrow + vec[2]
-  return(X)
-}
-
-"[.im" <- subset.im <-
-function(x, i, j, drop=TRUE, ...) {
-  if(verifyclass(i, "ppp", fatal=FALSE) && missing(j)) {
-    # 'i' is a point pattern
-    # Look up the greyscale values for the points of the pattern
-    values <- lookup.im(x, i$x, i$y, naok=TRUE)
-    if(drop) return(values[!is.na(values)]) else return(values)
-  }
-  if(verifyclass(i, "owin", fatal=FALSE) && missing(j)) {
-    # 'i' is a window
-    # if drop = FALSE, just set values outside window to NA
-    # if drop = TRUE, extract values for all pixels inside window
-    #                 as an image (if 'i' is a rectangle)
-    #                 or as a vector (otherwise)
-
-    xy <- expand.grid(y=x$yrow,x=x$xcol)
-    inside <- inside.owin(xy$x, xy$y, i)
-    if(!drop) { 
-      x$v[!inside] <- NA
-      return(x)
-    } else if(i$type != "rectangle") {
-      return(x$v[inside])
-    } else {
-      disjoint <- function(r, s) { (r[2] < s[1]) || (r[1] > s[2])  }
-      clip <- function(r, s) { c(max(r[1],s[1]), min(r[2],s[2])) }
-      inrange <- function(x, r) { (x >= r[1]) & (x <= r[2]) }
-      if(disjoint(i$xrange, x$xrange) || disjoint(i$yrange, x$yrange))
-        # empty intersection
-        return(numeric(0))
-      xr <- clip(i$xrange, x$xrange)
-      yr <- clip(i$yrange, x$yrange)
-      colsub <- inrange(x$xcol, xr)
-      rowsub <- inrange(x$yrow, yr)
-      return(im(x$v[rowsub,colsub], x$xcol[colsub], x$yrow[rowsub]))
-    } 
-  }
-  stop("The subset operation is undefined for this type of index")
-}
 
 
